@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2007 by Marco Lorrai                                    *
- *   marco.lorrai@abbeynet.it                                              *
+ *   Copyright (C) 2010 by Marco Lorrai                                    *
+ *   iking@aruba.it                                                        *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -30,6 +30,8 @@
 #include <wx/datetime.h>
 #include <sys/time.h>
 #include <time.h>
+#include <string.h>
+#include <stdlib.h>
 
 BEGIN_EVENT_TABLE( Frame, wxWindow )
 EVT_UPDATE_UI( PROGRESS_DIALOG_START, Frame::OnUpdateProgress )
@@ -90,6 +92,10 @@ void Frame::OpenDevice()
         frameFormat = VIDEO_PALETTE_RGB24;
     else if( Setting::GetInstance()->GetFrameFormat() == "RGB32" )
         frameFormat = VIDEO_PALETTE_RGB32;
+    else if( Setting::GetInstance()->GetFrameFormat() == "JPEG" )
+        frameFormat = VIDEO_PALETTE_JPEG;
+    else if( Setting::GetInstance()->GetFrameFormat() == "MPEG" )
+        frameFormat = VIDEO_PALETTE_MJPEG;
     else
         frameFormat = 0 /*AUTO*/;
     if ( !cam.openDevice( width, height, frameFormat ) ) {
@@ -137,7 +143,7 @@ void Frame::setFullscreen( bool enable )
 }
 
 void Frame::OnPaint( wxPaintEvent& event ) 
-{
+{   
     int w, h, frameW, frameH;    
     wxPaintDC dc( this );
     dc.GetSize( &w, &h );
@@ -187,8 +193,14 @@ void Frame::OnPaint( wxPaintEvent& event )
                 static_cast<AviUncompressed*>(rec)->Run();
             }
 
-            rec->addFrame( buffer );
-            rstatus = REC_CONTINUING;
+            if( rec->setup() ) {
+                rstatus = REC_NONE;
+                wxCommandEvent event( wxEVT_COMMAND_MENU_SELECTED, STOP_REC );
+                event.SetInt(1);
+                OnRecThreadTerminated(event);
+            } else {
+                rstatus = REC_CONTINUING;
+            }
         }
         else if ( rstatus == REC_CONTINUING ) {
             wxDateTime now = wxDateTime::UNow();
@@ -240,7 +252,7 @@ void Frame::OnPaint( wxPaintEvent& event )
                            0, 
                            scalex, 
                            scaley, 
-                           false);
+                           false);            
         }
         else {
             wxBitmap bit( wximg );            
@@ -253,6 +265,7 @@ void Frame::OnPaint( wxPaintEvent& event )
                            (1+y));
         }
     }
+    buffer = NULL;
 }
 
 void Frame::OnEraseBackground( wxEraseEvent &event )
@@ -284,9 +297,10 @@ bool Frame::SetResolution( const std::string &resolution, const std::string &fra
 }
 
 void Frame::OnIdle( wxIdleEvent& event ) 
-{
+{    
     static struct timeval tv;
     static bool show = false;
+
     if ( deviceOpen && cam.getFrame( &buffer ) ) {
         applyFilters();
         struct timeval tv_old = tv;
@@ -458,12 +472,17 @@ void Frame::applyFilters( )
     if(Setting::GetInstance()->GetNoise()) {
         if(!image) 
             image = new CImg<unsigned char>(cimg_from_rgb((unsigned char*)buffer, width, height));
-        image->noise();
+        image->noise(10);
     }
     if(Setting::GetInstance()->GetSharpen()) {
         if(!image) 
             image = new CImg<unsigned char>(cimg_from_rgb((unsigned char*)buffer, width, height));
-        image->sharpen();
+        image->sharpen(30, true);
+    }
+    if(Setting::GetInstance()->GetLaplacian()) {
+        if(!image)
+            image = new CImg<unsigned char>(cimg_from_rgb((unsigned char*)buffer, width, height));
+        image->laplacian();
     }
     if(Setting::GetInstance()->GetEdge())
         edge((unsigned char*)buffer, size, width);
@@ -479,7 +498,7 @@ void Frame::applyFilters( )
                 (dt.GetMillisecond()/100));
         memset(fgcolor, 255, 3);
         memset(bgcolor, 0, 3);
-        image->draw_text(text, width - 110, height - 15, fgcolor, bgcolor, 12);
+        image->draw_text(width - 120, height - 15, text, fgcolor, bgcolor, 12);
     }
     if(image) {
         rgb_from_cimg(*image, (unsigned char*)buffer);
@@ -538,9 +557,12 @@ void Frame::OnKeyDown( wxKeyEvent& event)
 CImg<unsigned char> Frame::cimg_from_rgb(unsigned char const* rgb, const unsigned int dimw, const unsigned int dimh) 
 {
     CImg<unsigned char> res(dimw, dimh, 1, 3, true);
-    unsigned char *pR = res.ptr(0, 0, 0, 0), *pG = res.ptr(0, 0, 0, 1), *pB=res.ptr(0, 0, 0, 2);
+    unsigned char
+          *pR = res.begin() + res.offset(0, 0, 0, 0), 
+          *pG = res.begin() + res.offset(0, 0, 0, 1), 
+          *pB = res.begin() + res.offset(0, 0, 0, 2);
     const unsigned char *ptrs = rgb;
-    for (unsigned int off=res.width*res.height; off>0; --off) {
+    for (unsigned int off = res.width() * res.height(); off > 0; --off) {
         *(pR++) = (unsigned char)*(ptrs++);
         *(pG++) = (unsigned char)*(ptrs++);
         *(pB++) = (unsigned char)*(ptrs++);
@@ -550,12 +572,12 @@ CImg<unsigned char> Frame::cimg_from_rgb(unsigned char const* rgb, const unsigne
 
 void Frame::rgb_from_cimg(CImg<unsigned char> const & cimg, unsigned char *buffer) 
 {
-    const unsigned int wh = cimg.dimx() * cimg.dimy();
+    const unsigned int wh = cimg.width() * cimg.height();
     unsigned char *nbuffer=buffer;
     const unsigned char
-            *ptr1 = cimg.ptr(0, 0, 0, 0),
-            *ptr2 = cimg.dim>1?cimg.ptr(0, 0, 0, 1):ptr1,
-            *ptr3 = cimg.dim>2?cimg.ptr(0, 0, 0, 2):ptr1;
+	*ptr1 = cimg.begin() + cimg.offset(0, 0, 0, 0),
+	*ptr2 = cimg.spectrum() > 1 ? cimg.begin() + cimg.offset(0, 0, 0, 1) : ptr1,
+	*ptr3 = cimg.spectrum() > 2 ? cimg.begin() + cimg.offset(0, 0, 0, 2) : ptr1;	
     for (unsigned int k=0; k<wh; k++) {
         *(nbuffer++) = (unsigned char)(*(ptr1++));
         *(nbuffer++) = (unsigned char)(*(ptr2++));
