@@ -176,6 +176,26 @@ bool VideoForLinux2::mMap(int w, int h) {
                     pixelFormat = V4L2_PIX_FMT_SBGGR8;
                     std::cout<<"Found V4L2_PIX_FMT_SBGGR8 pixel format"<<std::endl;                    
                 }
+                else if(argp.pixelformat == V4L2_PIX_FMT_SBGGR16) {
+                    fmt.fmt.pix.pixelformat = V4L2_PIX_FMT_SBGGR16;
+                    pixelFormat = V4L2_PIX_FMT_SBGGR16;
+                    std::cout<<"Found V4L2_PIX_FMT_SBGGR16 pixel format"<<std::endl;                    
+                }
+                else if(argp.pixelformat == V4L2_PIX_FMT_SGBRG8) {
+                    fmt.fmt.pix.pixelformat = V4L2_PIX_FMT_SGBRG8;
+                    pixelFormat = V4L2_PIX_FMT_SGBRG8;
+                    std::cout<<"Found V4L2_PIX_FMT_SGBRG8 pixel format"<<std::endl;                    
+                }
+                else if(argp.pixelformat == V4L2_PIX_FMT_SGRBG8) {
+                    fmt.fmt.pix.pixelformat = V4L2_PIX_FMT_SGRBG8;
+                    pixelFormat = V4L2_PIX_FMT_SGRBG8;
+                    std::cout<<"Found V4L2_PIX_FMT_SGRBG8 pixel format"<<std::endl;                    
+                }
+                else if(argp.pixelformat == V4L2_PIX_FMT_SPCA561) {
+                    fmt.fmt.pix.pixelformat = V4L2_PIX_FMT_SPCA561;
+                    pixelFormat = V4L2_PIX_FMT_SPCA561;
+                    std::cout<<"Found V4L2_PIX_FMT_SPCA561 pixel format"<<std::endl;                    
+                }
                 else if(argp.pixelformat == V4L2_PIX_FMT_BGR24) {
                     fmt.fmt.pix.pixelformat = V4L2_PIX_FMT_BGR24;
                     pixelFormat = V4L2_PIX_FMT_BGR24;
@@ -427,7 +447,11 @@ bool VideoForLinux2::getFrame(char **buffer)
         bayer2rgb24(( unsigned char* ) *buffer, tmp_buffer, width, height); 
         free(tmp_buffer);
     }
-    else if(pixelFormat == V4L2_PIX_FMT_SBGGR8) {         
+    else if(pixelFormat == V4L2_PIX_FMT_SBGGR8 || 
+		pixelFormat == V4L2_PIX_FMT_SBGGR16 || 
+		pixelFormat == V4L2_PIX_FMT_SGBRG8 ||
+		pixelFormat == V4L2_PIX_FMT_SPCA561 || 
+		pixelFormat ==  V4L2_PIX_FMT_SGRBG8) {         
         bayer2rgb24(( unsigned char* ) *buffer, ( unsigned char* ) buffers[buf.index].start, width, height); 
     }
     else if(pixelFormat == V4L2_PIX_FMT_BGR24 || pixelFormat == V4L2_PIX_FMT_SN9C10X
